gg_publish library
Classes
- GgPublish
- The command line interface for GgPublish.
- IsFeatureBranch
- Checks if the current git branch is a feature branch.
- IsLatestStatePublished
- Checks if the latest state is published
- IsMainBranch
- Checks if the current git branch is the main branch.
- IsOnPubDev
- Checks whether the package repository is published on pub.dev.
- IsPublished
- Checks if a package was published to pub.dev before.
- IsUpgraded
- Base class for all ggGit commands
- IsVersionPrepared
- Is the version in pubspec.yaml an increment of the version at pub.dev?
- MainBranch
- Returns the name of the repository's main branch.
- MergeMainIntoFeat
- Fetches origin and merges the remote main branch into the current branch.
- MockClient
- A Mock for the http.Client class using Mocktail
- MockIsLatestStatePublished
- A Mock for the IsLatestStatePublished class using Mocktail
- MockIsMainBranch
- Mock implementation of IsMainBranch.
- MockIsOnPubDev
- Mock implementation of IsOnPubDev.
- MockIsPublished
- A Mock for the IsPublished class using Mocktail
- MockIsUpgraded
- A Mock for the IsUpgraded class using Mocktail
- MockIsVersionPrepared
- A Mock for the HasPreparedVersions class using Mocktail
- MockMainBranch
- Mock implementation of MainBranch.
- MockMergeMainIntoFeat
- Mock implementation of MergeMainIntoFeat.
- MockPrepareNextVersion
- Mock class for PrepareNextVersion
- MockPublish
- A Mock for the Publish class using Mocktail
- MockPublishedVersion
- A Mock for the PublishedVersion class using Mocktail
- MockPublishTo
- Mock implementation of PublishTo
- PrepareNextVersion
- Creates a new version and writes it into pubspec.yaml
- Publish
- Base class for all ggGit commands
- PublishedVersion
- Returns the version published to pub.dev of a given dart package
- PublishTo
- Returns the value of pubspec.yaml's publish_to field.
Enums
- VersionIncrement
- Version increments
Typedefs
-
ProcessRunner
= Future<
ProcessResult> Function(String executable, List<String> arguments, {bool runInShell, String? workingDirectory}) - Signature for running a process.